package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Jul 20, 2022
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GetFieldName(structName interface{}) []string
获取结构体中字段的名称
func GetTagName(structName interface{}) []string
获取结构体中Tag的值,如果没有tag则返回字段值
Source Files
¶
Click to show internal directories.
Click to hide internal directories.