package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Jul 20, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func CreateInstance(index int, name string, order bool) *sortConfig
获取单例
func GetInstance() *sortConfig
获取单例
func NewSortConfig(index int, name string, order bool) *sortConfig
初始化
type SortConfig interface {
GetIndex() int
GetName() string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.